import bs
import bsUI
import time

class ChallengeEntryWindow(bsUI.PopupWindow):

    def __init__(self,challengeID,challengeActivity=None,position=(0,0),delegate=None,scale=None,offset=(0,0),onCloseCall=None):

        self._challengeID = challengeID

        self._onCloseCall = onCloseCall
        if scale is None: scale = 2.3 if bsUI.gSmallUI else 1.65 if bsUI.gMedUI else 1.23
        self._delegate = delegate
        self._transitioningOut = False

        self._challengeActivity = challengeActivity
        
        self._width = 340
        self._height = 290

        self._bgColor = (0.5,0.4,0.6)
        
        # creates our _rootWidget
        bsUI.PopupWindow.__init__(self,position=position,size=(self._width,self._height),
                                  scale=scale,bgColor=self._bgColor,offset=offset)
        self._state = None
        self._updateTimer = bs.Timer(1000,bs.WeakCall(self._update),repeat=True,timeType='real')
        self._update()

    def _rebuildForState(self,newState):
        
        # clear out previous state (if any)
        children = self._rootWidget.getChildren()
        for c in children: c.delete()

        self._state = newState
        
        print 'REBUILDING FOR STATE',self._state
        self._cancelButton = bs.buttonWidget(parent=self._rootWidget,position=(20,self._height-30),size=(50,50),scale=0.5,
                                             label='',color=self._bgColor,
                                             onActivateCall=self._onCancel,autoSelect=True,
                                             icon=bs.getTexture('crossOut'),iconScale=1.2)

        if self._state == 'error':
            titleStr = bs.getResource('coopSelectWindow.challengesText')
            bs.textWidget(parent=self._rootWidget,position=(self._width*0.5,self._height*0.5),size=(0,0),hAlign='center',vAlign='center',
                          scale=0.7,text=bs.getResource('errorText'),maxWidth=self._width*0.8)
        if self._state == 'ended':
            titleStr = bs.getResource('coopSelectWindow.challengesText')
            bs.textWidget(parent=self._rootWidget,position=(self._width*0.5,self._height*0.5),size=(0,0),hAlign='center',vAlign='center',
                          scale=0.7,text=bs.getResource('challengeEndedText'),maxWidth=self._width*0.8)
        else:
            titleStr = ''
            print 'Unrecognized state for ChallengeEntryWindow:',self._state
        
        self._titleText = bs.textWidget(parent=self._rootWidget,position=(self._width*0.5,self._height-20),size=(0,0),hAlign='center',vAlign='center',
                                        scale=0.6,text=titleStr,maxWidth=200,color=(1,1,1,0.4))

        
        
    def _update(self):
        print 'UPDATE',bs.getRealTime()

        # figure out what our state should be based on our current cached challenge data
        challenge = bsUI._getCachedChallenge(self._challengeID)
        if challenge is None: newState = 'error'
        elif challenge['end'] <= time.time(): newState = 'ended'
        else: newState = 'unknown'
            
        # if our state is changing, rebuild..
        if self._state != newState:
            self._rebuildForState(newState)
        
    def _onCancel(self):
        self._transitionOut()
        
    def _transitionOut(self):
        if not self._transitioningOut:
            self._transitioningOut = True
            self._saveState()
            bs.containerWidget(edit=self._rootWidget,transition='outScale')
            if self._onCloseCall is not None:
                self._onCloseCall()

    def onPopupCancel(self):
        bs.playSound(bs.getSound('swish'))
        self._onCancel()

    def _saveState(self):
        pass
        #sel = self._rootWidget.getSelectedChild()
        # if sel == self._payWithAdButton: selName = 'Ad'
        # else: selName = 'Tickets'
        #bs.getConfig()['Challenge Pay Selection'] = selName
        #bs.writeConfig()
    
    def _restoreState(self):
        pass
        # try: selName = bs.getConfig()['Tournament Pay Selection']
        # except Exception: selName = 'Tickets'
        # if selName == 'Ad' and self._payWithAdButton is not None: sel = self._payWithAdButton
        # else: sel = self._payWithTicketsButton
        # bs.containerWidget(edit=self._rootWidget,selectedChild=sel)

